[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# Swarms Cloud
Deploy your autonomous agents to the cloud with infinite scalability, 99% uptime, and a polymorphic api.


Base swarms code -> fastapi code is added to top and bottom -> agent is decorated with expose as api decorator -> file is parsed and then -> added onto yaml for -> skypilot


# Install
`pip install swarms-cloud`


# Stack
- Backend: FastAPI
- Skypilot for container management
- Stripe for payment tracking
- Postresql for database



# License
MIT